pub enum Body {
Empty(Empty<Bytes>),
Full(Full<Bytes>),
Stream(StreamBody<Pin<Box<dyn Stream<Item = Result<Frame<Bytes>, Error>> + Send + Sync>>>),
}Expand description
An HTTP body enum supporting empty, full bytes, and streamed frames for test support.
Variants
Empty(Empty<Bytes>)
An empty body.
Full(Full<Bytes>)
A body consisting of a single in-memory buffer of bytes.
Stream(StreamBody<Pin<Box<dyn Stream<Item = Result<Frame<Bytes>, Error>> + Send + Sync>>>)
A streamed body produced by an asynchronous stream of frames.
Implementations